# mkdocs-plugin-progress

A plugin for MkDocs that lets you know exactly what is happening during the build.
This is helpful for use cases such as debugging, or trying to find out which pages the builder is getting stuck on for longer periods of time.

## Usage

Please see [the documentation](https://docs.rdil.rocks/libraries/mkdocs-plugin-progress/).

## License

Copyright (c) 2020-current year Reece Dunham - under the Apache license, a copy of which can be found at https://www.apache.org/licenses/LICENSE-2.0
